@@ -1,3 +1,5 @@
+import functools
+import operator
 import sys
 import typing
 from collections.abc import Callable
@@ -58,7 +60,7 @@ if sys.version_info < (3, 9):
     def evaluate_forwardref(type_: ForwardRef, globalns: Any, localns: Any) -> Any:
         return type_._evaluate(globalns, localns)
 
-else:
+elif sys.version_info < (3, 12, 4):
 
     def evaluate_forwardref(type_: ForwardRef, globalns: Any, localns: Any) -> Any:
         # Even though it is the right signature for python 3.9, mypy complains with
@@ -67,6 +69,13 @@ else:
         # TypeError: ForwardRef._evaluate() missing 1 required keyword-only argument: 'recursive_guard'
         return cast(Any, type_)._evaluate(globalns, localns, recursive_guard=set())
 
+else:
+
+    def evaluate_forwardref(type_: ForwardRef, globalns: Any, localns: Any) -> Any:
+        # Pydantic 1.x will not support PEP 695 syntax, but provide `type_params` to avoid
+        # warnings:
+        return cast(Any, type_)._evaluate(globalns, localns, type_params=(), recursive_guard=set())
+
 
 if sys.version_info < (3, 9):
     # Ensure we always get all the whole `Annotated` hint, not just the annotated type.
@@ -192,9 +201,6 @@ if sys.version_info < (3, 9):
         return tp
 
 else:
-    from typing import _UnionGenericAlias  # type: ignore
-
-    from typing_extensions import _AnnotatedAlias
 
     def convert_generics(tp: Type[Any]) -> Type[Any]:
         """
@@ -214,7 +220,7 @@ else:
 
         # typing.Annotated needs special treatment
         if origin is Annotated:
-            return _AnnotatedAlias(convert_generics(args[0]), args[1:])
+            return Annotated[(convert_generics(args[0]), *args[1:])]  # type: ignore
 
         # recursively replace `str` instances inside of `GenericAlias` with `ForwardRef(arg)`
         converted = tuple(
@@ -228,7 +234,7 @@ else:
             return TypingGenericAlias(origin, converted)
         elif isinstance(tp, TypesUnionType):
             # recreate types.UnionType (PEP604, Python >= 3.10)
-            return _UnionGenericAlias(origin, converted)
+            return functools.reduce(operator.or_, converted)  # type: ignore
         else:
             try:
                 setattr(tp, '__args__', converted)
